@@ -3,7 +3,7 @@ from pathlib import Path
 from typing import List
 from pkg_resources import resource_filename
 
-PREFIX = "afl-qemu-trace"
+PREFIX = "afl-qemu-trace-"
 
 
 def qemu_path(platform: str) -> str:
